using Libdl
using Pkg

const depsfile = joinpath(@__DIR__, "deps.jl")

const libpath = get(ENV, "GMSH_LIB_PATH", nothing)

if libpath === nothing
    open(depsfile, "w") do io
        print(io,
            raw"""
            # This file is automatically generated
            # Do not edit
            using Gmsh_SDK_jll
            check_deps() = nothing
            include(joinpath(dirname(Gmsh_SDK_jll.libgmsh_path), "gmsh.jl"))
            """
            )
    end
else
    # For windows, you must create a link from `gmsh-*.*.dll` to `libgmsh.dll`
    libgmsh = find_library("libgmsh", [libpath])
    if isempty(libgmsh)
        @static if Sys.iswindows()
            @info "You may create a link from `gmsh-*.*.dll` to `libgmsh.dll`."
        end
        error("libgmsh is not found in $libpath.")
    end

    libgmsh_size = filesize(dlpath())

    open(depsfile, "w") do io
        println(io,
                """
                # This file is automatically generated
                # Do not edit
                function check_deps()
                    if libgmsh_size != filesize(Libdl.dlpath(libgmsh_size))
                        error("Gmsh library has changed, re-run Pkg.build(\\\"GmshTools\\\")")
                    end
                end
                include(joinpath(libpath, "gmsh.jl"))
                """
               )
        println(io, :(const libgmsh = $libgmsh))
        println(io, :(const libgmsh_size = $libgmsh_size))
    end
end
